@@ -1,6 +1,6 @@
 package Search::Elasticsearch::Client::0_90;
 
-our $VERSION='5.00';
+our $VERSION='5.01';
 use Search::Elasticsearch 5.00 ();
 
 1;
@@ -11,11 +11,11 @@ use Search::Elasticsearch 5.00 ();
 
 =head1 NAME
 
-Search::Elasticsearch::Client::0_90 - Thin client with full support for Elasticsearch 2.x APIs
+Search::Elasticsearch::Client::0_90 - Thin client with full support for Elasticsearch 0_90.x APIs
 
 =head1 VERSION
 
-version 5.00
+version 5.01
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ with L<Search::Elasticsearch> as follows:
         client => "0_90::Direct"
     );
 
-See C<Search::Elasticsearch::Client::0_90::Direct> for documentation
+See L<Search::Elasticsearch::Client::0_90::Direct> for documentation
 about how to use the client itself.
 
 =head1 AUTHOR
@@ -46,5 +46,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 2.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 0_90.x APIs
 
